# depends on getpars(object)
setMethod("freepars","mix",
	function(object) {
		free <- sum(!getpars(object,which="fixed"))
		free
	}
)

# depends on nlin(object) and getpars(object)
setMethod("freepars","depmix.fitted",
	function(object) {
		free <- sum(!getpars(object,which="fixed"))
 		free <- free-nlin(object) 
		free
	}
)

# depends on nlin(object) and getpars(object)
setMethod("freepars","mix.fitted",
	function(object) {
		free <- sum(!getpars(object,which="fixed"))
		free <- free-nlin(object) 
		free
	}
)

setMethod("nlin","mix.fitted",
	function(object) {
		conMat <- object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE]
		if(nrow(conMat)==0) nlin <- 0 
		else nlin <- qr(conMat)$rank
		nlin
	}
)

setMethod("nlin","depmix.fitted",
	function(object) {
		conMat <- object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE]
		if(nrow(conMat)==0) nlin <- 0 
		else nlin <- qr(conMat)$rank
		nlin
	}
)

